==> blanco.plugin.resourcebundle_1.2.0-src.zip: blancoResourceBundlePlugin/src/blanco/plugin/resourcebundle/wizards/BlancoResourceBundleWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2005 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.resourcebundle.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.resourcebundle.resourcebundle.BlancoResourceBundleWizardResourceBundle;

/**
 * \[Xoh`vpeBt@CуANZTJava\[XR[h𐶐 EclipsevOC̃EBU[hłB
 * 
 * ̃\[XR[hblancoResourceBundlëꕔłB<br>
 * 
 * @author IGA Tosiki
 */
public class BlancoResourceBundleWizardPage4 extends WizardPage {
    /**
     * \[XohANZT̃CX^XB
     */
    private BlancoResourceBundleWizardResourceBundle fBundleWizard = null;

    /**
     * EBU[hy[WNX̃RXgN^B
     * 
     * @param selection
     *            IڃIuWFNgB
     */
    public BlancoResourceBundleWizardPage4(ISelection selection) {
        super("wizardPage");
        this.fBundleWizard = new BlancoResourceBundleWizardResourceBundle();
        setTitle(fBundleWizard.getPage04Title());
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg001());
        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg002());
        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg003());
        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg004());
        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg005());
        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg006());
        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg007());

        setControl(container);
    }
}

==> blanco.plugin.resourcebundle_1.3.5-src.zip: blancoResourceBundlePlugin/src/blanco/plugin/resourcebundle/wizards/BlancoResourceBundleWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2005 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.resourcebundle.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.resourcebundle.resourcebundle.BlancoResourceBundleWizardResourceBundle;

/**
 * \[Xoh`vpeBt@CуANZTJava\[XR[h𐶐 EclipsevOC̃EBU[hłB
 * 
 * ̃\[XR[hblancoResourceBundlëꕔłB<br>
 * 
 * @author IGA Tosiki
 */
public class BlancoResourceBundleWizardPage4 extends WizardPage {
    /**
     * \[XohANZT̃CX^XB
     */
    private BlancoResourceBundleWizardResourceBundle fBundleWizard = null;

    /**
     * EBU[hy[WNX̃RXgN^B
     * 
     * @param selection
     *            IڃIuWFNgB
     */
    public BlancoResourceBundleWizardPage4(ISelection selection) {
        super("wizardPage");
        this.fBundleWizard = new BlancoResourceBundleWizardResourceBundle();
        setTitle(fBundleWizard.getPage04Title());
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg001());
        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg002());
        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg003());
        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg004());
        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg005());
        new Label(container, SWT.NONE).setText(fBundleWizard.getPage04Msg006());

        new Label(container, SWT.NONE).setText("  4.ꂽ\[XR[hi[tH_");
        new Label(container, SWT.NONE).setText("    Eblanco/main (Java)");

        setControl(container);
    }
}
